@@ -1,8 +1,11 @@
-static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.47/cmds/RCS/c.c,v 2.46 1997/04/18 12:13:15 zeus Exp $";
+static char *rcsid = "$Header: /sanguine/homes/zeus/Blind-2.48/cmds/RCS/c.c,v 2.48 1999/03/14 00:48:48 zeus Exp zeus $";
 
 /*
 
  * $Log: c.c,v $
+ * Revision 2.48  1999/03/14 00:48:48  zeus
+ * *** empty log message ***
+ *
  * Revision 2.46  1997/04/18 12:13:15  zeus
  * *** empty log message ***
  *
@@ -19,6 +22,8 @@ static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.47/cmds/RCS/c.c,v 2.46
 #include "enterturn-g.h"
 #include "cmds.h"
 #include "cmds-g.h"
+#include "misc-g.h"
+#include "list.h"
 
 extern player *players;
 extern tmppname *tmpname;
@@ -52,7 +57,7 @@ c_cmd (char *buf, player * P)
     }
     else
     {
-      if (!legal_name (t, EMPIRE))
+      if (legal_name (t, EMPIRE) != 0)
       {
         error (err_tmp);
         return;
