@@ -1,8 +1,11 @@
-static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.46/cmds/RCS/n.c,v 2.46 1997/04/18 12:13:56 zeus Exp zeus $";
+static char *rcsid = "$Header: /sanguine/homes/zeus/Blind-2.48/cmds/RCS/n.c,v 2.47 1998/04/15 21:34:50 zeus Exp $";
 
 /*
 
  * $Log: n.c,v $
+ * Revision 2.47  1998/04/15 21:34:50  zeus
+ * *** empty log message ***
+ *
  * Revision 2.46  1997/04/18 12:13:56  zeus
  * *** empty log message ***
  *
@@ -39,7 +42,7 @@ n_cmd (char *buf, player * P)
   int tnum, rnum;
 
   cmd_init(buf);
-  p = ninputplanet ();
+  p = ninputplanet (P);
   if (p)
   {
     if (p->owner != P)
