@@ -1,10 +1,11 @@
-static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.47/RCS/new-game.c,v 2.47 1998/04/15 21:34:17 zeus Exp zeus $";
+static char *rcsid = "$Header: /sanguine/homes/zeus/Blind-2.48/RCS/new-game.c,v 2.48 1999/03/14 00:46:08 zeus Exp zeus $";
 
 /*
  * $Log: new-game.c,v $
- * Revision 2.47  1998/04/15 21:34:17  zeus
+ * Revision 2.48  1999/03/14 00:46:08  zeus
  * *** empty log message ***
  *
+ * Revision 2.47  1998/04/15 21:34:17  zeus
  * Revision 2.46.0.1  1997/05/27 21:04:56  zeus
  * Revision 2.46  1997/04/18 12:06:12  zeus
  * Revision 2.45  1996/12/31  23:40:54  zeus
@@ -28,10 +29,12 @@ static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.47/RCS/new-game.c,v 2.4
 
 #define NOTIMEB
 
-#include "protos/common.h"
-#include "protos/prototypes.h"
-#include "protos/new-game.h"
-#include "protos/i-o.h"
+#include "common.h"
+#include "prototypes.h"
+#include "new-game.h"
+#include "i-o.h"
+#include "str.h"
+#include "list.h"
 
 extern planet *planets;
 extern player *players;
@@ -377,7 +380,7 @@ planet_value (planet * ph, planet * p)
   pdf = p_dist_fudge (ph, p);
   prf = p_resource_fudge (p->resources);
   psf = p_size_fudge (p->size);
-  return (pdf * prf * psf * p->size);
+  return (pdf * prf * psf);
 }
 
 /* find and move largest contibutor to player's cumulative planet total */
@@ -526,25 +529,3 @@ manual_move_planet (void)
   p->x = newx;
   p->y = newy;
 }
-
-/* Lifted from cmds/Cmds-lib.c so we don't have to include it */
-/* This is a "safe" strncpy- null termination guarenteed, and no
-   overrun (given correct sizes) */
-
-void
-hstrncpy (char *a, const char *b, const int sz)
-{
-  int x;
-
-  a[0] = '\0';
-  if (b == NULL)
-    return;
-  for (x = 0; b[x] && (x < sz); x++)
-  {
-    a[x] = b[x];
-  }
-  if (sz == MAXTEXT)
-    a[sz - 1] = '\0';
-  if (x < sz)
-    a[x] = '\0';
-}
